
import click

from agileupstate import EXITCODE


def print_check_message(text) -> bool:
    click.echo(b'\xE2\x9C\x94' + f' {text}'.encode())
    return True


def print_cross_message(text, leave=False) -> bool:
    click.echo(b'\xE2\x9D\x8C' + f' {text}'.encode())
    if leave:
        exit(EXITCODE)
    else:
        return True



import json
from pathlib import Path

import click
import yaml

from agileupstate.client import Client
from agileupstate.terminal import print_cross_message


class State:

    def __init__(self, state_file='siab-state.yml', state_export_file='siab-state-export.sh'):
        self.client = Client()
        self.state_file = state_file
        self.state_export_file = state_export_file
        self.values_path = self.client.values_path
        self.state_name = self.client.id + '-' + self.client.cloud + '-' + self.client.location1 + '-' + self.client.context
        self.state_name_underscore = self.client.id + '_' + self.client.cloud + '_' + self.client.location1 + '_' + self.client.context

        self.vault_state_path = 'siab-state/' \
                                + self.client.id + '-' \
                                + self.client.cloud + '-' \
                                + self.client.location1 + '-' \
                                + self.client.context

        self.vault_tfstate_path = 'siab-tfstate/' \
                                  + self.client.id + '-' \
                                  + self.client.cloud + '-' \
                                  + self.client.location1 + '-' \
                                  + self.client.context

        self.siab_state_data = {'siab-id': self.client.id,
                                'siab-cloud': self.client.cloud,
                                'siab-location1': self.client.location1,
                                'siab-location2': self.client.location2,
                                'siab-context': self.client.context,
                                'siab-values-path': self.client.values_path,
                                }

    def validate(self, data: dict):
        self.client.validate(data)

    def update(self, data: dict):
        self.client.update(data)

    @staticmethod
    def read_tfstate(file='terraform.tfstate') -> dict:
        file_path = Path(file)
        if file_path.is_file():
            with open(file, 'r') as tfstate_file:
                tfstate_content = json.loads(tfstate_file.read())
            return tfstate_content
        else:
            print_cross_message(f'Could not read from state file {file}!', leave=True)

    @staticmethod
    def write_tfstate(tfstate_content, file='terraform.tfstate') -> None:
        click.secho(f'- Writing {file}', fg='blue')
        with open(file, 'w') as tfstate_file:
            json.dump(tfstate_content, tfstate_file)

    def write(self) -> None:
        file = Path(self.state_file)
        click.secho(f'- Writing {file}', fg='blue')
        with open(file, 'w') as f:
            yaml.dump(self.siab_state_data, f, sort_keys=False, default_flow_style=False)

    def write_exports(self, state_values_filename) -> None:
        file = Path(self.state_export_file)
        state_values = self.read(state_values_filename)
        username = state_values['connection']['username']
        password = state_values['connection']['password']
        line1 = f'export TF_VAR_admin_username={username}'
        line2 = f'export TF_VAR_admin_password={password}'
        line3 = f'export TF_VAR_siab_name={self.state_name}'
        line4 = f'export TF_VAR_siab_name_underscore={self.state_name_underscore}'
        click.secho(f'- Writing {file}', fg='blue')
        with open(file, 'w') as f:
            for key, value in state_values['connection'].items():
                f.write('export SIAB_{}={}\n'.format(str(key).upper(), value))
            for key, value in state_values['cloud'].items():
                f.write('export TF_VAR_{}={}\n'.format(key, value))
            f.write(line1 + '\n')
            f.write(line2 + '\n')
            f.write(line3 + '\n')
            f.write(line4 + '\n')

    @staticmethod
    def read(filename) -> dict:
        file_path = Path(filename)
        if file_path.is_file():
            click.secho(f'- Reading {file_path}', fg='blue')
            with open(file_path, 'r') as f:
                return yaml.safe_load(f)
        else:
            print_cross_message(f'Could not read from state file {file_path}!', leave=True)



import os
from sys import platform

import click
import pkg_resources

from agileupstate.terminal import print_check_message, print_cross_message


def get_version_string() -> str:
    return f"AgileUp State Version: {pkg_resources.get_distribution('agileupstate').version}"


def supported_os() -> bool:
    if platform == 'linux' or platform == 'linux2':
        return True
    elif platform == 'darwin':
        return True
    elif platform == 'win32':
        return False


class Client:

    def __init__(self, updated=False):
        self.version = get_version_string()
        self.updated = updated

        if supported_os():
            print_check_message(f'Client machine supported {platform}')
        else:
            print_cross_message(f'Client machine not supported {platform}!', leave=True)

        try:
            self.id = os.environ['SIAB_ID']
            self.cloud = os.environ['SIAB_CLOUD']
            self.location1 = os.environ['SIAB_LOCATION1']
            self.location2 = os.environ['SIAB_LOCATION2']
            self.context = os.environ['SIAB_CONTEXT']
            self.values_path = os.environ['SIAB_VALUES_PATH']
            self.vault_addr = os.environ['VAULT_ADDR']
            self.vault_token = os.environ['VAULT_TOKEN']
            self.display()
        except KeyError as e:
            print_cross_message(f'Missing key {e}!', leave=True)

    def display(self) -> None:
        if self.updated:
            message = f'- Updated client ({self.id} {self.cloud} {self.location1} {self.context}) {self.version}'
            click.secho(message, fg='yellow')
        else:
            message = f'- Running client ({self.id} {self.cloud} {self.location1} {self.context}) {self.version}'
            click.secho(message, fg='blue')

    def vault_addr(self) -> str:
        return self.vault_addr

    def vault_token(self) -> str:
        return self.vault_token

    def values_path(self) -> str:
        return self.values_path

    def validate(self, data: dict) -> None:
        try:
            if self.id != data['siab-id']:
                print_cross_message(f'Client out of sync error {self.id}!', leave=True)
            if self.cloud != data['siab-cloud']:
                print_cross_message(f'Client out of sync error {self.cloud}!', leave=True)
            if self.location1 != data['siab-location1']:
                print_cross_message(f'Client out of sync error {self.location1}!', leave=True)
            if self.location2 != data['siab-location2']:
                print_cross_message(f'Client out of sync error {self.location2}!', leave=True)
            if self.context != data['siab-context']:
                print_cross_message(f'Client out of sync error {self.context}!', leave=True)
            if self.values_path != data['siab-values-path']:
                print_cross_message(f'Client out of sync error {self.values_path}!', leave=True)
            self.display()
        except KeyError as e:
            print_cross_message(f'Missing key {e}!', leave=True)

    def update(self, data) -> None:
        self.id = data['siab-id']
        self.cloud = data['siab-cloud']
        self.location1 = data['siab-location1']
        self.location2 = data['siab-location2']
        self.context = data['siab-context']
        self.values_path = data['siab-values-path']
        self.updated = True
        self.display()



import os

import click
import winrm

from agileupstate.state import State
from agileupstate.terminal import print_cross_message, print_check_message

PRIVATE_KEY_PEM = 'vm-rsa-private-key.pem'
INVENTORY = 'inventory.ini'


def opener(path, flags):
    return os.open(path, flags, 0o600)


def reset_linux(state: State) -> None:
    if os.path.isfile(INVENTORY):
        os.remove(INVENTORY)
    with open(INVENTORY, 'w') as f:
        f.write('[' + state.state_name_underscore + ']\n')


def reset_windows(state: State) -> None:
    if os.path.isfile(INVENTORY):
        os.remove(INVENTORY)
    with open(INVENTORY, 'w') as f:
        f.write('[' + state.state_name_underscore + ']\n')


def switch_domain_if_present(dns: str) -> str:
    try:
        override = os.environ['SIAB_DOMAIN']
        click.secho(f'- Overriding domain to {override}', fg='yellow')
        return dns.split('.')[0] + '.' + override
    except KeyError:
        return dns


def windows_bottom(state: State, username, password, pki) -> None:
    ca_trust_path, cert_pem, cert_key_pem = pki
    with open(INVENTORY, 'a') as f:
        f.write('[' + f'{state.state_name_underscore}:vars' + ']\n')
        f.write(f'ansible_user={username}' + '\n')
        f.write(f'ansible_password={password}' + '\n')
        f.write('ansible_connection=winrm' + '\n')
        f.write('ansible_port=5986' + '\n')
        f.write(f'ansible_winrm_ca_trust_path={ca_trust_path}' + '\n')
        f.write(f'ansible_winrm_cert_pem={cert_pem}' + '\n')
        f.write(f'ansible_winrm_cert_key_pem={cert_key_pem}' + '\n')
        f.write('ansible_winrm_transport=certificate' + '\n')


def create_windows_inventory(state: State, tfstate_content, pki) -> None:
    try:
        ips = tfstate_content['outputs']['public_ip_address']['value']
        dnss = tfstate_content['outputs']['public_ip_dns_name']['value']
        admin_username = tfstate_content['outputs']['admin_username']['value']
        admin_password = tfstate_content['outputs']['admin_password']['value']
        if ips is None:
            print_cross_message('Expected public_ip_address in terraform output!', leave=True)
        if dnss is None:
            print_cross_message('Expected public_ip_dns_name in terraform output!', leave=True)
        if admin_username is None:
            print_cross_message('Expected admin_username in terraform output!', leave=True)
        if admin_password is None:
            print_cross_message('Expected admin_password in terraform output!', leave=True)
        print_check_message(f'Creating Windows inventory for {dnss}')
        reset_windows(state)
        for dns in dnss:
            with open(INVENTORY, 'a') as f:
                f.write(switch_domain_if_present(dns) + '\n')
        windows_bottom(state, admin_username, admin_password, pki)
        click.secho(f'- Writing inventory file {INVENTORY}', fg='blue')
    except KeyError as e:
        print_cross_message(f'Missing key {e}!', leave=True)


def create_linux_inventory(state: State, tfstate_content) -> None:
    try:
        ips = tfstate_content['outputs']['public_ip_address']['value']
        dnss = tfstate_content['outputs']['public_ip_dns_name']['value']
        admin_username = tfstate_content['outputs']['admin_username']['value']
        admin_password = tfstate_content['outputs']['admin_password']['value']
        if ips is None:
            print_cross_message('Expected public_ip_address in terraform output!', leave=True)
        if dnss is None:
            print_cross_message('Expected public_ip_dns_name in terraform output!', leave=True)
        if admin_username is None:
            print_cross_message('Expected admin_username in terraform output!', leave=True)
        if admin_password is None:
            print_cross_message('Expected admin_password in terraform output!', leave=True)
        print_check_message(f'Creating Windows inventory for {dnss}')
        reset_linux(state)
        for dns in dnss:
            with open(INVENTORY, 'a') as f:
                f.write(switch_domain_if_present(dns) + f' ansible_ssh_private_key_file={PRIVATE_KEY_PEM}\n')
        click.secho(f'- Writing inventory file {INVENTORY}', fg='blue')
    except KeyError as e:
        print_cross_message(f'Missing key {e}!', leave=True)


def ping_windows(auth) -> None:
    session = winrm.Session('https://ags-w-arm1.meltingturret.io:5986',
                            ca_trust_path='chain.meltingturret.io.pem',
                            cert_pem='devops@meltingturret.io.pem',
                            cert_key_pem='devops@meltingturret.io.key',
                            transport='certificate', auth=auth)
    response = session.run_cmd('ipconfig', ['/all'])
    print(response.std_out)



def indent(message) -> str:
    return f'  {message}'


def truncate(text, length=-50) -> str:
    """ Right truncate string with message.

    :param text: string to truncate
    :param length: negative length
    :return:
    """
    return f'...{text[length:]}'



from zipfile import ZipFile

import click

from agileupstate.ansible import ping_windows, create_windows_inventory, create_linux_inventory
from agileupstate.client import get_version_string, Client
from agileupstate.terminal import print_check_message, print_cross_message
from agileupstate.vault import address, is_ready, create_state, load_state, create_tfstate, load_tfstate, \
    load_vault_file

CONTEXT_SETTINGS = dict(help_option_names=['-h', '--help'])


@click.group(help='CLI to manage pipeline states.')
def cli() -> int:
    pass


@cli.command(help='Display the current version.')
def version() -> None:
    click.echo(get_version_string())


@cli.command(help='Check client configuration.')
def check() -> None:
    click.secho('Checking client configuration', fg='green')
    if is_ready():
        print_check_message('Vault backend is available')
        Client()
    else:
        print_cross_message(f'Vault backend failed from: {address()}', leave=True)


@cli.command(help='Create vault states.')
def create() -> None:
    click.secho('- Create vault states', fg='green')
    create_state()


@cli.command(help='Save tfstates to vault.')
def save() -> None:
    click.secho('- Save tfstates to vault', fg='green')
    state = load_state()
    tfstate_content = state.read_tfstate()
    create_tfstate(state, tfstate_content)


@cli.command(help='Load states from vault.')
def load() -> None:
    click.secho('- Load states from vault', fg='green')
    state = load_state()
    tfstate_content = load_tfstate()
    state.write_tfstate(tfstate_content)


@cli.command(help='Generate cloud init zip file for mTLS data.')
@click.option('--server-path', required=True, help='Vault path to windows WinRM server pfx file.')
@click.option('--client-path', required=True, help='Vault path to windows WinRM client pfx file.')
def cloud_init(server_path, client_path) -> None:
    filename1 = load_vault_file(server_path)
    filename2 = load_vault_file(client_path)
    with ZipFile('cloud-init.zip', 'w') as z:
        z.write(filename1)
        z.write(filename2)
    click.secho('- Writing cloud-init.zip', fg='blue')


@cli.command(help='Create ansible inventory file for WinRM connections.')
@click.option('--ca-trust-path', envvar='SIAB_CA_TRUST_PATH', required=True, help='Vault path ca trust file.')
@click.option('--cert-pem', envvar='SIAB_CERT_PEM', required=True, help='Vault path to client cert pem file.')
@click.option('--cert-key-pem', envvar='SIAB_CERT_KEY_PEM', required=True, help='Vault path to client key pem file.')
def inventory_windows(ca_trust_path, cert_pem, cert_key_pem) -> None:
    click.secho('- Create ansible inventory file for WinRM connections', fg='green')
    state = load_state()
    tfstate_content = state.read_tfstate()
    filename1 = load_vault_file(ca_trust_path)
    filename2 = load_vault_file(cert_pem)
    filename3 = load_vault_file(cert_key_pem)
    create_windows_inventory(state, tfstate_content, (filename1, filename2, filename3))


@cli.command(help='Create ansible inventory file for SSH connections.')
def inventory_linux() -> None:
    click.secho('- Create ansible inventory file for SSH connections', fg='green')
    state = load_state()
    tfstate_content = state.read_tfstate()
    create_linux_inventory(state, tfstate_content)


@cli.command(help='Check connection.')
@click.option('--username', required=True, help='Username for windows access.')
@click.option('--password', required=True, help='Password for windows access.')
def ping(username, password) -> None:
    click.secho(f'- Checking Windows WinRM connection for user {username}', fg='green')
    ping_windows((username, password))


if __name__ == '__main__':
    exit(cli())



# -*- coding: utf-8 -*-
from setuptools import setup

package_dir = \
{'': 'src'}

packages = \
['agileupstate']

package_data = \
{'': ['*']}

install_requires = \
['PyYAML>=5.4.1,<6.0.0',
 'click>=8.1,<9.0',
 'hvac>=1.0.2,<2.0.0',
 'prettytable>=3.3.0,<4.0.0',
 'pywinrm>=0.4.3,<0.5.0']

entry_points = \
{'console_scripts': ['agileupstate = agileupstate.cli:cli']}

setup_kwargs = {
    'name': 'agileupstate',
    'version': '0.0.43',
    'description': 'State mangement tool for Future Agile CICD',
    'long_description': '# AgileUp State\n\nPython 3.8+ project to manage AgileUP pipeline states with the following features:\n\n* Linux and Windows compatible project.\n* Defines state model.\n* Saves and fetches states from vault.\n* Exports private key for Linux SSH connections.\n* Exports client PKI data for Windows WinRM connections.\n* Creates cloud init zip file for mTLS connection data to Windows WinRM hosts.\n* Exports ansible inventories for both Linux(SSH) and Windows(WinRM) connections.\n* Provides simple connectivity tests.\n\n## Prerequisites\n\nThis project uses poetry is a tool for dependency management and packaging in Python. It allows you to declare the \nlibraries your project depends on, it will manage (install/update) them for you. \n\nUse the installer rather than pip [installing-with-the-official-installer](https://python-poetry.org/docs/master/#installing-with-the-official-installer).\n\n```sh\npoetry self add poetry-bumpversion\n```\n\n```sh\npoetry -V\nPoetry (version 1.2.0)\n```\n\n### Windows Path\n\nInstall poetry from powershell in admin mode.\n\n```shell\n(Invoke-WebRequest -Uri https://install.python-poetry.org -UseBasicParsing).Content | py -\n```\n\nThe path will be `C:\\Users\\<YOURUSER>\\AppData\\Roaming\\Python\\Scripts\\poetry.exe` which you will need to add to your system path.\n\n### Windows GitBash\n\nWhen using gitbash you can setup an alias for the poetry command:\n\n```shell\nalias poetry="\\"C:\\Users\\<YOURUSER>\\AppData\\Roaming\\Python\\Scripts\\poetry.exe\\""\n```\n\n## Getting Started\n\n```sh\npoetry update\n```\n\n```sh\npoetry install\n```\n\n## Development\n\nThis project uses the [hvac](https://github.com/hvac/hvac) python module and to develop locally you can run vault\nas a docker service as detailed here [local docker vault](https://hub.docker.com/_/vault). For local development vault \nsetup follow the [VAULT](VAULT.md) guide for information.\n\nCheck your connection with the following command, note in development mode vault should not be sealed.\n\n```shell\nexport VAULT_ADDR=\'http://localhost:8200\'\nexport VAULT_TOKEN=\'8d02106e-b1cd-4fa5-911b-5b4e669ad07a\'\n\npoetry run agileupstate check\n```\n\n## Required Environment State Variables\n\n| Variable         | Description                                                     |\n|------------------|-----------------------------------------------------------------|\n| SIAB_ID          | Unique environment ID.                                          |\n| SIAB_CLOUD       | Cloud vendor API mnemonic.                                      |\n| SIAB_LOCATION1   | Cloud vendor defined cloud location, uksouth, etc.              |\n| SIAB_LOCATION2   | Cloud vendor defined cloud location, UK South, etc.             |\n| SIAB_CONTEXT     | Environment context, e.g. dev. test, prod.                      |\n| SIAB_VALUES_PATH | Vault path to common environment values to be exported.         |\n| SIAB_DOMAIN      | Optional public domain that overrides cloud provided DNS names. |\n\n`SIAB_LOCATION`: Azure has a different location string between "accounts" and "resources" and only `uksouth` is useful\nto the automation, but we must also provide `UK South` for resource groups.\n\n`SIAB_VALUES_PATH`: Rather than load variables into the delivery platform environment, there can be many, a better option\nis to define a YML file that contains all the required common variables for a specific environment and have the user upload\nthat to vault. This application can then download the YML data file and convert it into an exports file that can be sourced \nby the pipelines. These environment values that are exported can then be used by this project and other utilities such as\nterraform, ansible and powershell.\n\n`SIAB_DOMAIN`: Cloud DNS services might in some cases provide a DNS domain that is not the same as the public internet\ndomain required by the project, for example server1.uksouth.cloudapp.azure.com might optionally be server1.meltingturret.io.\n\n`username/password`: These values are common across the environment, for example Ubuntu Azure images use a `username=azureuser`,\nand so it simplifies configuration if the same credentials are used for Linux and Windows environments running in Azure for \nadministration access, client administration access as well as PFX certificate files used on Windows for WinRM certificate \nauthentication. For AWS `ubuntu` is the username for Ubuntu images the same approach can be taken there.\n\n**Required environment inputs:**\n\n> These values should be setup in your CD platforms environment variables.\n\n```shell\nexport SIAB_ID=001\nexport SIAB_CLOUD=arm\nexport SIAB_LOCATION1=uksouth\nexport SIAB_LOCATION2="UK South"\nexport SIAB_CONTEXT=dev\nexport SIAB_VALUES_PATH=siab-state/001-arm-uksouth-dev/siab-values/siab-values.yml\n```\n\n**Required values inputs (stored in vault path `SIAB_VALUES_PATH`):**\n\n```yaml\nconnection:\n  url: https://server1.meltingturret.io:5986\n  username: azureuser\n  password: mypassword\n  ca_trust_path: siab-client/chain.meltingturret.io.pem\n  cert_pem: siab-client/azureuser@meltingturret.io.pem\n  cert_key_pem: siab-client/azureuser@meltingturret.io.key\ncloud:\n  group_owner: Paul Gilligan\n  group_department: DevOps\n  group_location: UK South\n```\n\n## Required Supporting Data\n\nSome data is generated only once and thus can be uploaded to vault manually. \n\n**Uploading values file:**\n\n```shell\nbase64 ./siab-values.yml | vault kv put secret/siab-state/001-arm-uksouth-dev/siab-values/siab-values.yml file=-\n```\n\n**Uploading pfx files:**\n\n```shell\nbase64 ./server1.meltingturret.io.pfx | vault kv put secret/siab-pfx/server1.meltingturret.io.pfx file=-\nbase64 ./azureuser@meltingturret.io.pfx | vault kv put secret/siab-pfx/azureuser@meltingturret.io.pfx file=-\n```\n\n**Uploading pki files:**\n\n```shell\nbase64 ./chain.meltingturret.io.pem | vault kv put secret/siab-client/chain.meltingturret.io.pem file=-\nbase64 ./azureuser@meltingturret.io.key | vault kv put secret/siab-client/azureuser@meltingturret.io.key file=-\nbase64 ./azureuser@meltingturret.io.pem | vault kv put secret/siab-client/azureuser@meltingturret.io.pem file=-\n```\n\n## Provision Use Case\n\nExample steps required for the Windows terraform provision use case shown below. \n\n```shell\nagileupstate cloud-init --server-path=siab-pfx/ags-w-arm1.meltingturret.io.pfx --client-path=siab-pfx/devops@meltingturret.io.pfx\nagileupstate create\nsource ./siab-state-export.sh                                                \nterraform init\nterraform apply -auto-approve\nagileupstate save\n```\n\nExample steps required for the Linux terraform provision use case shown below. \n\n```shell\nagileupstate create\nsource ./siab-state-export.sh                                                \nterraform init\nterraform apply -auto-approve\nagileupstate save\n```\n\n## Destroy Use Case\n\nExample steps required for recovering system state use case shown below which might be for example to destroy an environment. \n\n```shell\nagileupstate load\nsource ./siab-state-export.sh                                                \nterraform init\nterraform destroy -auto-approve\n```\n\n## Ansible Use Case\n\nExample steps required for the Windows ansible use case shown below. \n\n```shell\nagileupstate load\nsource ./siab-state-export.sh                                                  \nagileupstate inventory-windows --ca-trust-path=siab-client/chain.meltingturret.io.pem --cert-pem=siab-client/azureuser@meltingturret.io.pem --cert-key-pem=siab-client/devops@meltingturret.io.key\nansible-inventory -i inventory.ini --list\nansible -i inventory.ini "${TF_VAR_siab_name_underscore}" -m win_ping\n```\n\nExample steps required for the Linux ansible use case shown below. \n\n```shell\nagileupstate load\nsource ./siab-state-names.sh                        \nagileupstate inventory-linux\nansible-inventory -i inventory.ini --list\nANSIBLE_HOST_KEY_CHECKING=True ansible -i inventory.ini --user "${TF_VAR_admin_username}" "${TF_VAR_siab_name_underscore}" -m ping\n```\n\n## Exports Use Case\n\nThe `yml` file from `SIAB_VALUES_PATH` is exported to the file `siab-state-export.sh` with the contents as shown in the \nexample below which can then be used by downstream utilities. \n\n```shell\nexport SIAB_URL=https://server1.meltingturret.io:5986\nexport SIAB_USERNAME=azureuser\nexport SIAB_PASSWORD=mypassword\nexport SIAB_CA_TRUST_PATH=siab-client/chain.meltingturret.io.pem\nexport SIAB_CERT_PEM=siab-client/azureuser@meltingturret.io.pem\nexport SIAB_CERT_KEY_PEM=siab-client/azureuser@meltingturret.io.key\nexport TF_VAR_group_owner=Paul Gilligan\nexport TF_VAR_group_department=DevOps\nexport TF_VAR_group_location=UK South\nexport TF_VAR_admin_username=azureuser\nexport TF_VAR_admin_password=mypassword\nexport TF_VAR_siab_name=001-arm-uksouth-dev\nexport TF_VAR_siab_name_underscore=001_arm_uksouth_dev\n```\n\n```shell\nsource ./siab-state-export.sh\n```\n\n## Cloud Init Data Use Case\n\nExample cloud init command that generates the zip file that is loaded onto Windows machines for WimRM certificate authentication. \n\n```shell\npoetry run agileupstate cloud-init --server-path=siab-pfx/ags-w-arm1.meltingturret.io.pfx --client-path=siab-pfx/azureuser@meltingturret.io.pfx\n```\n\n## Ansible Windows Inventory Use Case\n\n`inventory.ini` is generated with the target(s) and configuration information for a successful SSH connection from Ansible. \n\n**When `export SIAB_DOMAIN=meltingturret.io`:**\n\n```ini\n[001_arm_uksouth_dev]\nags-w-arm1.meltingturret.io\n[001_arm_uksouth_dev:vars]\nansible_user=azureuser\nansible_password=heTgDg!J4buAv5kc\nansible_connection=winrm\nansible_port=5986\nansible_winrm_ca_trust_path=chain.meltingturret.io.pem\nansible_winrm_cert_pem=azureuser@meltingturret.io.pem\nansible_winrm_cert_key_pem=azureuser@meltingturret.io.key\nansible_winrm_transport=certificate\n```\n\n## Ansible Linux Inventory Use Case\n\n`inventory.ini` is generated with the target(s) and configuration information for a successful SSH connection from Ansible. \n\n**When `export SIAB_DOMAIN=meltingturret.io`:**\n\n```ini\n[001_arm_uksouth_dev]\nags-w-arm1.meltingturret.io ansible_ssh_private_key_file=vm-rsa-private-key.pem\n```\n\n## Run\n```sh\npoetry run agileupstate\n```\n\n## Lint\n```sh\npoetry run flake8\n```\n\n## Test\n```sh\npoetry run pytest\n```\n\n## Publish\n\n* By default we are using [PYPI packages](https://packaging.python.org/en/latest/tutorials/installing-packages/). \n* Create yourself an access token for PYPI and then follow the instructions.\n\n```sh\nexport PYPI_USERNAME=__token__ \nexport PYPI_PASSWORD=<Your API Token>\npoetry publish --build --username $PYPI_USERNAME --password $PYPI_PASSWORD\n```\n\n## Versioning\nWe use [SemVer](http://semver.org/) for versioning. For the versions available, see the [tags on this repository](https://github.com/Agile-Solutions-GB-Ltd/agileup/tags). \n\n## Releasing\n\nWe are using [poetry-bumpversion](https://github.com/monim67/poetry-bumpversion) to manage release versions.\n\n```sh\npoetry version patch\n```\n\n## Dependency\n\nOnce the release has been created it is now available for you to use in other python projects via:\n\n```sh\npip install agileupstate\n```\n\nAnd also for poetry projects via:\n\n```sh\npoetry add agileupstate\n```\n\n## Contributing\n\nPlease read [CONTRIBUTING.md](CONTRIBUTING.md) for details on our code of conduct, and the process for submitting pull requests to us.\n\n## License\n\nThis project is licensed under the Apache License, Version 2.0 - see the [LICENSE](LICENSE) file for details\n\n\n\n',
    'author': 'agileturret',
    'author_email': 'Paul.Gilligan@agilesolutions.co.uk',
    'maintainer': 'None',
    'maintainer_email': 'None',
    'url': 'https://github.com/Agile-Solutions-GB-Ltd/agileupstate',
    'package_dir': package_dir,
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'entry_points': entry_points,
    'python_requires': '>=3.8,<4.0',
}


setup(**setup_kwargs)
